Credit

Struct Credit 

pub struct Credit {
    pub role: Role,
    pub order: Option<i16>,
    pub name: Vec<Name>,
    pub credited_person_info: Option<CreditedPersonInfo>,
    pub character: Option<Vec<Character>>,
}

Fields

role: Role

Attribute role will be used to define the credited role, see Credited Role for values. It is highly recommended to include at least one director and/or major actor.

order: Option<i16>

Attribute order will be used to sequence the credits for this item. If order is not provided, credits will be sequenced based on order of appearance in the feed. Typically credits are provided in billing order.

name: Vec<Name>

Specifies the official name of the credited entity.

1 to 255 characters in length.

credited_person_info: Option<CreditedPersonInfo>character: Option<Vec<Character>>