pub struct LocalPremiereDate {
pub value: NaiveDate,
pub countries: Vec<String>,
}Fields
value: NaiveDatecountries: Vec<String>Attribute countries must be used to specify the countries that the premiere date applies to. Value should be the two-letter country codes as defined in the ISO 3166 International Standard. Multiple countries can be grouped together in a comma-separated value string.